@@ -12,6 +12,7 @@ from .core import (
     run_validation,
     update_project_validation_steps,
 )
+from .exceptions import NpValidatorError
 from .models import (
     Processor,
     ValidationStep,
@@ -37,7 +38,9 @@ __all__ = [
     "Validator",
     "Processor",
     "load_ValidationStep",
+    "dump_ValidationResults",
     "autogenerate_validation_steps",
     "update_project_validation_steps",
     "version",
+    "NpValidatorError",
 ]
